tidy_comb: Tidy combine

View source: R/tidycomb.R

tidy_combR Documentation

Tidy combine

Description

Get all combinations from a dataframe column or from a list

Usage

tidy_comb(data, base, ...)

## S3 method for class 'data.frame'
tidy_comb(data, base, ...)

## Default S3 method:
tidy_comb(data, base, ...)

Arguments

data

data object containing the list of words, either a list or a data.frame

base

the base word to compare with all the words

...

if data is a data.frame, the col where the words to combine are

Value

a tibble with all possible combination of elements from a list

Examples

tidy_comb(iris, "this", Species)
tidy_comb(state.name, "Paris")

tidystringdist documentation built on May 5, 2026, 1:07 a.m.