tidy_comb_all: Tidy combine all

View source: R/tidycomb.R

tidy_comb_allR Documentation

Tidy combine all

Description

Get all combinations from a dataframe column

Usage

tidy_comb_all(data, ...)

## S3 method for class 'data.frame'
tidy_comb_all(data, ...)

## Default S3 method:
tidy_comb_all(data, ...)

Arguments

data

a list or a data.frame with the elements to combine

...

if data is a data.frame, the col where the words to combine are

Value

a tibble with all possible combination of elements from a list

Examples

tidy_comb_all(iris, Species)
tidy_comb_all(state.name)


tidystringdist documentation built on May 5, 2026, 1:07 a.m.