| tidy_comb | R Documentation |
Get all combinations from a dataframe column or from a list
tidy_comb(data, base, ...)
## S3 method for class 'data.frame'
tidy_comb(data, base, ...)
## Default S3 method:
tidy_comb(data, base, ...)
data |
data object containing the list of words, either a list or a data.frame |
base |
the base word to compare with all the words |
... |
if data is a data.frame, the col where the words to combine are |
a tibble with all possible combination of elements from a list
tidy_comb(iris, "this", Species)
tidy_comb(state.name, "Paris")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.